@@ -1,7 +1,6 @@
 import logging
 import requests
 from celery.exceptions import MaxRetriesExceededError
-from django_scopes import scopes_disabled
 from pretix.base.models import Order, OrderPosition
 from pretix.base.services.tasks import ProfiledEventTask
 from pretix.celery_app import app
@@ -22,8 +21,7 @@ logger = logging.getLogger(__name__)
 def matrix_inviter_invite(
     self, event: int, order: int, order_position: int, invitation_reason: str
 ):
-    with scopes_disabled():
-        order_position = OrderPosition.objects.get(pk=order_position)
+    order_position = OrderPosition.objects.get(pk=order_position)
 
     user_matrix_id = order_position.meta_info_data.get("question_form_data", {}).get(
         "matrix_inviter_matrix_id"
@@ -32,8 +30,7 @@ def matrix_inviter_invite(
     if not user_matrix_id:
         return
 
-    with scopes_disabled():
-        order = Order.objects.get(pk=order)
+    order = Order.objects.get(pk=order)
     server = event.settings.matrix_inviter_matrix_server
     token = event.settings.matrix_inviter_authorization_token
     room_id = matrix_room_id(server, event.settings.matrix_inviter_matrix_room)
